@@ -884,7 +884,7 @@ class Askdata(SignUp):
             if (df[col].dtypes == "datetime64[ns]"):
                 df[col] = df[col].astype("str")
 
-        df = df.where(pd.notnull(df), None)
+        #df = df.where(pd.notnull(df), None)
 
 
         if "/" in workspace:
@@ -897,7 +897,24 @@ class Askdata(SignUp):
             else:
                 datasetSlug = dataset_slug
 
-        url = self.base_url + "/smartbot/agents/{}/datasets/{}/data_table".format(agentSlug, datasetSlug)
+        url = self.base_url + "/smartbot/agent-slugs/{}/datasets/{}/parquet".format(agentSlug, datasetSlug)
+
+        s = requests.Session()
+        s.keep_alive = False
+        retries = Retry(total=5, backoff_factor=1, status_forcelist=[502, 503, 504])
+        s.mount('https://', HTTPAdapter(max_retries=retries))
+
+        headers = {
+            "Content-Type": "application/json",
+            "Authorization": "Bearer" + " " + self._token
+        }
+
+        response = s.post(url=url, files={"file": open(df.to_parquet(),'rb')}, headers=headers)
+        response.raise_for_status()
+        dataset = response.json()
+        dataset_id = dataset["id"]
+
+        '''url = self.base_url + "/smartbot/agents/{}/datasets/{}/data_table".format(agentSlug, datasetSlug)
 
         fields = []
         for column in df.columns:
@@ -940,7 +957,7 @@ class Askdata(SignUp):
             response = s.post(url=url, json=body, headers=headers)
             response.raise_for_status()
             dataset = response.json()
-            dataset_id = dataset["id"]
+            dataset_id = dataset["id"]'''
 
         if (dataset_name != ""):
             url = self.base_url + "/smartbot/agents/" + dataset["agents"][0] + "/datasets/" + dataset_id + "/settings"
